#include "math.h"

vector v_forward, v_up, v_right;

float () random = #7;
int (float f) ftoi = #0x000f0000 + 110;
float (int i) itof = #0x000f0000 + 111;
vector (vector v) normalize = #9;
float (vector v) vlen = #12;
float (vector v) vectoyaw = #13;
float (float v) rint = #36;
float (float v) floor = #37;
float (float v) ceil = #38;
float (float f) fabs = #43;
vector (vector v) vectoangles = #51;

float (float x) sin = #0;
float (float x) cos = #0;
float (float x) tan = #0;
float (float x) asin = #0;
float (float x) acos = #0;
float (float x) atan = #0;
float (float y, float x) atan2 = #0;
float (float x) log = #0;
float (float x) log2 = #0;
float (float x) log10 = #0;
float (float x, float y) pow = #0;
float (float x) sinh = #0;
float (float x) cosh = #0;
float (float x) tanh = #0;
float (float x) asinh = #0;
float (float x) acosh = #0;
float (float x) atanh = #0;
float (float x) sqrt = #0;
float (float x) cbrt = #0;
float (float x, float y) hypot = #0;
